Package: BGLR
Version: 1.1.2
Title: Bayesian Generalized Linear Regression
Author: Gustavo de los Campos, Paulino Perez Rodriguez
Maintainer: Paulino Perez Rodriguez <perpdgo@colpos.mx>
Depends: R (>= 3.5.0)
Imports: truncnorm, MASS, methods
Description: Bayesian Generalized Linear Regression.
License: GPL-3
NeedsCompilation: yes
Packaged: 2024-04-01 22:16:52 UTC; pperez
Repository: CRAN
Date/Publication: 2024-04-02 05:10:02 UTC
Built: R 4.2.3; aarch64-apple-darwin20; 2024-04-02 07:25:16 UTC; unix
Archs: BGLR.so.dSYM
