Package: BGLR
Version: 1.1.4
Title: Bayesian Generalized Linear Regression
Authors@R: c(person(given = "Gustavo",
                      family = "de los Campos",
                      role = "aut",
                      email="gdeloscampos@gmail.com"),
             person(given = "Paulino",
                      family = "Perez Rodriguez",
                      role = c("aut", "cre"),
                      email = "perpdgo@colpos.mx"))
Depends: R (>= 3.5.0)
Imports: truncnorm, MASS, methods
Suggests: pROC, Matrix, survival
Description: Bayesian Generalized Linear Regression.
License: GPL-3
NeedsCompilation: yes
Packaged: 2025-03-26 21:53:37 UTC; paulino
Author: Gustavo de los Campos [aut],
  Paulino Perez Rodriguez [aut, cre]
Maintainer: Paulino Perez Rodriguez <perpdgo@colpos.mx>
Repository: CRAN
Date/Publication: 2025-03-27 04:00:12 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-26 12:48:42 UTC; unix
Archs: BGLR.so.dSYM
