useDynLib(BGLR, .registration=TRUE)

importFrom("graphics", "abline", "plot")
importFrom("stats", "cor", "dbeta", "dchisq", "dexp", "dgamma",
           "dnorm", "model.frame", "model.matrix", "pnorm", "qnorm",
           "rbeta", "rbinom", "rchisq", "rgamma", "rnorm", "runif",
           "var", "weighted.mean","sd","complete.cases","factanal","varimax",
           "cov")
importFrom("utils", "read.table")
importFrom("truncnorm", "rtruncnorm")
importFrom("MASS","mvrnorm")
importFrom("methods", "is")

export(BGLR,
       BLR,
       read_bed,
       read_ped, 
       write_bed,
       readBinMat,
       getVariances,
       BFDR,
       BLRCross,
       BLRXy,
       Multitrait,
       readBinMatMultitrait,
       xpnd,
       vech,
       getGCovar)

#Actually we are not using S4 methods...
#exportMethods(BGLR)

#S3method(effects, BGLR)
S3method(plot, BGLR)
S3method(residuals,BGLR)
S3method(predict,BGLR)
S3method(summary,BGLR)
